/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IGGDIALOGANIMATINGPROGRESS_H
#define IGGDIALOGANIMATINGPROGRESS_H


#include "iggdialog.h"


class iggWidgetNumberLabel;
class iggWidgetTextLabel;


class iggDialogAnimatingProgress : public iggDialog
{

public:

	iggDialogAnimatingProgress(iggMainWindow *parent);

	virtual const iString& GetToolTip() const;

	void Animate();

	void Pause(bool s);
	inline bool IsPaused() const { return mPaused; }

	void Cancel();
	inline bool IsCancelled() const { return mCancelled; }

protected:

	virtual void CompleteConstructionBody();
	virtual bool CanBeClosed();

	bool mCancelled, mPaused;
	iggWidgetNumberLabel *mCurrentFrame, *mCurrentRecord;
	iggWidgetTextLabel *mWarning;
	iggFrame *mInfoFrame, *mWarningFrame;
	int mLastRecord, mLastFrame;
};

#endif  //  IGGDIALOGANIMATINGPROGRESS_H
